@@ -1,3 +1,5 @@
+//! Haptic devices, which give the players to feedback by some force.
+
 use bitflags::bitflags;
 use std::{ffi::CStr, marker::PhantomData, os::raw::c_int, ptr::NonNull};
 
@@ -17,26 +19,36 @@ pub use playing::*;
 use self::effect::HapticEffect;
 
 bitflags! {
+    /// A property of the haptic device.
     pub struct HapticProperty: u32 {
+        /// Supported a constant effect.
         const CONSTANT = 1 << 0;
+        /// Supported a sine wave periodic effect.
         const SINE = 1 << 1;
+        /// Supported a left/right effect.
         const LEFT_RIGHT = 1 << 2;
+        /// Supported a triangle wave periodic effect.
         const TRIANGLE = 1 << 3;
+        /// Supported an upwards sawtooth wave periodic effect.
         const SAW_TOOTH_UP = 1 << 4;
+        /// Supported a downwards sawtooth wave periodic effect.
         const SAW_TOOTH_DOWN = 1 << 5;
+        /// Supported a ramp effect.
         const RAMP = 1 << 6;
-        const SPRING = 1 << 7;
-        const DAMPER = 1 << 8;
-        const INERTIA = 1 << 9;
-        const FRICTION = 1 << 10;
+        /// Supported a custom effect.
         const CUSTOM = 1 << 11;
+        /// Supported setting the global gain.
         const GAIN = 1 << 12;
+        /// Supported setting auto-center.
         const AUTO_CENTER = 1 << 13;
+        /// Supported querying the status of the effect.
         const STATUS = 1 << 14;
+        /// Supported pausing the effect.
         const PAUSE = 1 << 15;
     }
 }
 
+/// A haptic device.
 pub struct Haptic {
     ptr: NonNull<bind::SDL_Haptic>,
 }
@@ -50,16 +62,19 @@ impl std::fmt::Debug for Haptic {
 }
 
 impl Haptic {
+    /// Returns the name of the haptic device.
     pub fn name(&self) -> String {
         let index = unsafe { bind::SDL_HapticIndex(self.ptr.as_ptr()) };
         let cstr = unsafe { CStr::from_ptr(bind::SDL_HapticName(index)) };
         cstr.to_string_lossy().to_string()
     }
 
+    /// Returns the numbers of the axes on the haptic device.
     pub fn num_axes(&self) -> u32 {
         unsafe { bind::SDL_HapticNumAxes(self.ptr.as_ptr()) as u32 }
     }
 
+    /// Returns whether the effect is supported on the haptic device.
     pub fn is_effect_supported(&self, effect: &HapticEffect) -> bool {
         let mut raw = effect.clone().into_raw();
         unsafe {
@@ -68,6 +83,7 @@ impl Haptic {
         }
     }
 
+    /// Constructs the [`PendingEffect`] from the effect specification, or `Err` on failure.
     pub fn new_effect(&self, effect: &HapticEffect) -> Result<PendingEffect> {
         if !self.is_effect_supported(effect) {
             return Err(SdlError::UnsupportedFeature);
@@ -81,20 +97,24 @@ impl Haptic {
         }
     }
 
+    /// Returns the capacity of the effects on the haptic device.
     pub fn effects_creation_capacity(&self) -> usize {
         unsafe { bind::SDL_HapticNumEffects(self.ptr.as_ptr()) as usize }
     }
 
+    /// Returns the maximum numbers of playing the effects at same time on the haptic device.
     pub fn effects_playing_capacity(&self) -> usize {
         unsafe { bind::SDL_HapticNumEffectsPlaying(self.ptr.as_ptr()) as usize }
     }
 
+    /// Stops all the playing effect.
     pub fn stop_all_effect(&self) {
         unsafe {
             bind::SDL_HapticStopAll(self.ptr.as_ptr());
         }
     }
 
+    /// Sets the global gain. If not supported, this has no effects.
     pub fn set_gain(&self, gain: u32) {
         if !self.property().contains(HapticProperty::GAIN) {
             return;
@@ -105,6 +125,7 @@ impl Haptic {
         }
     }
 
+    /// Sets auto-center. If not supported, this has no effects.
     pub fn set_auto_center(&self, auto_center: u32) {
         if !self.property().contains(HapticProperty::AUTO_CENTER) {
             return;
@@ -117,11 +138,13 @@ impl Haptic {
         }
     }
 
+    /// Queries a property on the haptic device.
     pub fn property(&self) -> HapticProperty {
         let bits = unsafe { bind::SDL_HapticQuery(self.ptr.as_ptr()) };
         HapticProperty::from_bits(bits).unwrap()
     }
 
+    /// Pauses the haptic device and converts into [`PausedHaptic`].
     pub fn pause(self) -> PausedHaptic {
         unsafe {
             bind::SDL_HapticPause(self.ptr.as_ptr());
@@ -130,11 +153,13 @@ impl Haptic {
     }
 }
 
+/// A haptic device but frozen not to interact.
 pub struct PausedHaptic {
     haptic: Haptic,
 }
 
 impl PausedHaptic {
+    /// Unpauses the haptic device and converts into [`Haptic`].
     pub fn unpause(self) -> Haptic {
         unsafe {
             bind::SDL_HapticUnpause(self.haptic.ptr.as_ptr());
@@ -143,10 +168,11 @@ impl PausedHaptic {
     }
 }
 
-#[derive(Default)]
+/// All of recognized haptic devices at initialized.
 pub struct HapticSet(Vec<Haptic>);
 
 impl HapticSet {
+    /// Constructs and initializes the system and recognizes haptic devices.
     pub fn new() -> Self {
         let num_haptics = unsafe {
             bind::SDL_InitSubSystem(bind::SDL_INIT_HAPTIC);
@@ -162,11 +188,18 @@ impl HapticSet {
         )
     }
 
+    /// Returns the haptic devices.
     pub fn haptics(&self) -> &[Haptic] {
         &self.0
     }
 }
 
+impl Default for HapticSet {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
 impl Drop for HapticSet {
     fn drop(&mut self) {
         for haptic in &self.0 {
